@@ -2,9 +2,13 @@
 from patch import applyPatches
 from zope.interface import implements
 from interfaces import IPatchUtility
+from logging import getLogger, INFO
 
 APPLIED = False
 
+log = getLogger('portalfactoryfix')
+log.setLevel(INFO)
+
 class PatchApplicator( object ):
 
     implements( IPatchUtility )
@@ -12,6 +16,7 @@ class PatchApplicator( object ):
     def __init__( self ):
         global APPLIED
         if not APPLIED:
+            log.info("Applied Portal Factory No Write Patch")
             applyPatches()
             APPLIED = True
             
